==> chessproblem.ui-0.3.2.tar.gz: chessproblem.ui-0.3.2/bin/cpe.py <==
#!/usr/bin/env python

# Copyright 2012 Stefan Hoening
# 
# This file is part of the "Chess-Problem-Editor" software.
# 
# Chess-Problem-Editor is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Chess-Problem-Editor is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Diese Datei ist Teil der Software "Chess-Problem-Editor".
# 
# Chess-Problem-Editor ist Freie Software: Sie koennen es unter den Bedingungen
# der GNU General Public License, wie von der Free Software Foundation,
# Version 3 der Lizenz oder (nach Ihrer Option) jeder spaeteren
# veroeffentlichten Version, weiterverbreiten und/oder modifizieren.
# 
# Chess-Problem-Editor wird in der Hoffnung, dass es nuetzlich sein wird, aber
# OHNE JEDE GEWAEHRLEISTUNG, bereitgestellt; sogar ohne die implizite
# Gewaehrleistung der MARKTFAEHIGKEIT oder EIGNUNG FUER EINEN BESTIMMTEN ZWECK.
# Siehe die GNU General Public License fuer weitere Details.
# 
# Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
# Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.


from optparse import OptionParser

import chessproblem.ui as tkinter_ui
import chessproblem.ui.gtk_ui as gtk_ui

from chessproblem.config import CONFIGDIR, ensure_config_dir, load_logging_config

ensure_config_dir()
load_logging_config()

parser = OptionParser()

parser.add_option("-u", "--user-interface", dest="user_interface", default="gtk",
        help="select user interface implementation, valid values are 'tkinter' and 'gtk'")

(options, args) = parser.parse_args()

if options.user_interface == 'tkinter':
    frame = tkinter_ui.MainFrame()
    frame.mainloop()
elif options.user_interface == 'gtk':
    if len(args) == 1:
        frame = gtk_ui.MainFrame(args[0])
    else:
        frame = gtk_ui.MainFrame()
    frame.main()
else:
    print 'Invalid user interface option: %s' % options.user_interface

==> chessproblem.ui-1.0.0rc5.tar.gz: chessproblem.ui-1.0.0rc5/bin/cpe.py <==
#!/usr/bin/env python

# Copyright 2012 Stefan Hoening
# 
# This file is part of the "Chess-Problem-Editor" software.
# 
# Chess-Problem-Editor is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Chess-Problem-Editor is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Diese Datei ist Teil der Software "Chess-Problem-Editor".
# 
# Chess-Problem-Editor ist Freie Software: Sie koennen es unter den Bedingungen
# der GNU General Public License, wie von der Free Software Foundation,
# Version 3 der Lizenz oder (nach Ihrer Option) jeder spaeteren
# veroeffentlichten Version, weiterverbreiten und/oder modifizieren.
# 
# Chess-Problem-Editor wird in der Hoffnung, dass es nuetzlich sein wird, aber
# OHNE JEDE GEWAEHRLEISTUNG, bereitgestellt; sogar ohne die implizite
# Gewaehrleistung der MARKTFAEHIGKEIT oder EIGNUNG FUER EINEN BESTIMMTEN ZWECK.
# Siehe die GNU General Public License fuer weitere Details.
# 
# Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
# Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.


from argparse import ArgumentParser

from chessproblem.ui import MainFrame

from chessproblem.config import create_config

parser = ArgumentParser()

parser.add_argument('filename', nargs='?')
parser.add_argument('-c', '--config_dir', nargs=1, dest='config_dir',
        help='specifies the configuration directory', default=None)

args = parser.parse_args()

if args.config_dir != None:
    cpe_config = create_config(args.config_dir[0])
else:
    cpe_config = create_config(None)

if args.filename != None:
    frame = MainFrame(cpe_config, args.filename)
else:
    frame = MainFrame(cpe_config)
frame.main()
